# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Stars(Component):
    """A Stars component.
Wrapped from [react-stars](https://github.com/n49/react-stars).

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- char (string; optional):
    Which character you want to use as a star.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color1 (string; optional):
    Color of inactive star (this supports any CSS valid value).

- color2 (string; optional):
    Color of selected or active star.

- count (number; optional):
    How many total stars you want.

- edit (boolean; optional):
    Should you be able to select rating or just see rating (for
    reusability).

- half (boolean; optional):
    Should component use half stars, if not the decimal part will be
    dropped otherwise normal algebra rools will apply to round to half
    stars.

- size (number | string; optional):
    Size of stars (in px).

- value (number; optional):
    Set rating value."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_grocery'
    _type = 'Stars'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, class_name=Component.UNDEFINED, value=Component.UNDEFINED, count=Component.UNDEFINED, char=Component.UNDEFINED, color1=Component.UNDEFINED, color2=Component.UNDEFINED, size=Component.UNDEFINED, edit=Component.UNDEFINED, half=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'char', 'class_name', 'color1', 'color2', 'count', 'edit', 'half', 'size', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'char', 'class_name', 'color1', 'color2', 'count', 'edit', 'half', 'size', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Stars, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Masonry(Component):
    """A Masonry component.
Wrapped from [react-masonry-component](https://github.com/eiriklv/react-masonry-component).

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    children.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- disableImagesLoaded (boolean; optional):
    default False.

- elementType (string; optional):
    default 'div'.

- enableResizableChildren (boolean; optional):
    enableResizableChildren.

- imagesLoadedOptions (dict; optional):
    default {}.

- options (dict; optional):
    masonry options.

    `options` is a dict with keys:

    - columnWidth (number | string; optional):
        Aligns items to a horizontal grid.

    - containerStyle (dict; optional):
        CSS styles that are applied to the container element.

    - fitWidth (boolean; optional):
        Sets the width of the container to fit the available number of
        columns, based the size of container's parent element. When
        enabled, you can center the container with CSS.

    - gutter (number; optional):
        Adds horizontal space between item elements.

    - horizontalOrder (boolean; optional):
        Lays out items to (mostly) maintain horizontal left-to-right
        order.

    - initLayout (boolean; optional):
        Enables layout on initialization. Enabled by default
        initLayout: True.

    - itemSelector (string; optional):
        Specifies which child elements will be used as item elements
        in the layout.

    - originLeft (boolean; optional):
        Controls the horizontal flow of the layout. By default, item
        elements start positioning at the left, with originLeft: True.
        Set originLeft: False for right-to-left layouts.

    - originTop (boolean; optional):
        Controls the vertical flow of the layout. By default, item
        elements start positioning at the top, with originTop: True.
        Set originTop: False for bottom-up layouts.

    - percentPosition (boolean; optional):
        Sets item positions in percent values, rather than pixel
        values. percentPosition: True works well with percent-width
        items, as items will not transition their position on resize.

    - resize (boolean; optional):
        Adjusts sizes and positions when window is resized. Enabled by
        default resize: True.

    - stagger (number | string; optional):
        Staggers item transitions, so items transition incrementally
        after one another. Set as a CSS time format, '0.03s', or as a
        number in milliseconds, 30.

    - stamp (string; optional):
        Specifies which elements are stamped within the layout.
        Masonry will layout items below stamped elements.

    - transitionDuration (number | string; optional):
        Duration of the transition when items change position or
        appearance, set in a CSS time format. Default:
        transitionDuration: '0.4s'.

- style (dict; optional):
    style.

- updateOnEachImageLoad (boolean; optional):
    default False and works only if disableImagesLoaded is False."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_grocery'
    _type = 'Masonry'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, class_name=Component.UNDEFINED, elementType=Component.UNDEFINED, options=Component.UNDEFINED, disableImagesLoaded=Component.UNDEFINED, updateOnEachImageLoad=Component.UNDEFINED, imagesLoadedOptions=Component.UNDEFINED, onImagesLoaded=Component.UNDEFINED, enableResizableChildren=Component.UNDEFINED, onLayoutComplete=Component.UNDEFINED, onRemoveComplete=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'class_name', 'disableImagesLoaded', 'elementType', 'enableResizableChildren', 'imagesLoadedOptions', 'options', 'style', 'updateOnEachImageLoad']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'class_name', 'disableImagesLoaded', 'elementType', 'enableResizableChildren', 'imagesLoadedOptions', 'options', 'style', 'updateOnEachImageLoad']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Masonry, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ResponsiveGridLayout(Component):
    """A ResponsiveGridLayout component.
Wrapped from [react-grid-layout](https://github.com/react-grid-layout/react-grid-layout).

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    children.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- allowOverlap (boolean; optional):
    If True, grid can be placed one over the other. If set, implies
    `preventCollision`.

- autoSize (boolean; optional):
    If True, the container height swells and contracts to fit
    contents.

- breakpoints (dict; optional):
    {name: pxVal}, e.g. {lg: 1200, md: 996, sm: 768, xs: 480}
    Breakpoint names are arbitrary but must match in the cols and
    layouts objects.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- cols (dict; optional):
    # of cols. This is a breakpoint -> cols map, e.g. {lg: 12, md: 10,
    ...}.

- compactType (a value equal to: 'vertical', 'horizontal'; optional):
    Compaction type.

- containerPadding (optional):
    containerPadding (in pixels). Can be specified either as
    horizontal and vertical padding, e.g. `[10, 10]` or as a
    breakpoint -> containerPadding map, e.g. `{lg: [10, 10], md: [10,
    10], ...}.

- draggableCancel (string; optional):
    A CSS selector for tags that will not be draggable. For example:
    draggableCancel:'.MyNonDraggableAreaClassName' If you forget the
    leading . it will not work. .react-resizable-handle\" is always
    prepended to this value.

- draggableHandle (string; optional):
    A CSS selector for tags that will act as the draggable handle. For
    example: draggableHandle:'.MyDragHandleClassName' If you forget
    the leading . it will not work.

- droppingItem (dict; optional):
    Configuration of a dropping element. Dropping element is a
    \"virtual\" element which appears when you drag over some element
    from outside. It can be changed by passing specific parameters: i
    - id of an element w - width of an element h - height of an
    element.

    `droppingItem` is a dict with keys:

    - h (number; optional)

    - i (string; optional)

    - w (number; optional)

- isBounded (boolean; optional):
    Flag.

- isDraggable (boolean; optional):
    Flag.

- isDroppable (boolean; optional):
    If True, droppable elements (with `draggable={True}` attribute)
    can be dropped on the grid. It triggers \"onDrop\" callback with
    position and event object as parameters. It can be useful for
    dropping an element in a specific position.

- isResizable (boolean; optional):
    Flag.

- layout (list; optional):
    // Layout is an array of object with the format: {x: number, y:
    number, w: number, h: number} The index into the layout must match
    the key used on each item component. If you choose to use custom
    keys, you can specify that key in the layout array objects like
    so: {i: string, x: number, y: number, w: number, h: number}.

- layouts (dict; optional):
    layouts is an object mapping breakpoints to layouts. e.g. {lg:
    Layout, md: Layout, ...}.

- margin (optional):
    margin (in pixels). Can be specified either as horizontal and
    vertical margin, e.g. `[10, 10]` or as a breakpoint -> margin map,
    e.g. `{lg: [10, 10], md: [10, 10], ...}.

- preventCollision (boolean; optional):
    If True, grid items won't change position when being dragged over.
    If `allowOverlap` is still False, this simply won't allow one to
    drop on an existing object.

- resizeHandle (dash component; optional):
    Custom component for resize handles See `handle` as used in
    https://github.com/react-grid-layout/react-resizable#resize-handle
    Your component should have the class `.react-resizable-handle`, or
    you should add your custom class to the `draggableCancel` prop.

- resizeHandles (list; optional):
    Defines which resize handles should be rendered Allows for any
    combination of: 's' - South handle (bottom-center) 'w' - West
    handle (left-center) 'e' - East handle (right-center) 'n' - North
    handle (top-center) 'sw' - Southwest handle (bottom-left) 'nw' -
    Northwest handle (top-left) 'se' - Southeast handle (bottom-right)
    'ne' - Northeast handle (top-right).

- rowHeight (number; optional):
    Rows have a static height, but you can change this based on
    breakpoints if you like.

- transformScale (number; optional):
    If parent DOM node of ResponsiveReactGridLayout or ReactGridLayout
    has \"transform: scale(n)\" css property, we should set scale
    coefficient to avoid render artefacts while dragging.

- useCSSTransforms (boolean; optional):
    Uses CSS3 translate() instead of position top/left. This makes
    about 6x faster paint performance.

- width (number; optional):
    This allows setting the initial width on the server side. This is
    required unless using the HOC <WidthProvider> or similar."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, class_name=Component.UNDEFINED, width=Component.UNDEFINED, autoSize=Component.UNDEFINED, breakpoints=Component.UNDEFINED, cols=Component.UNDEFINED, draggableCancel=Component.UNDEFINED, draggableHandle=Component.UNDEFINED, compactType=Component.UNDEFINED, layout=Component.UNDEFINED, layouts=Component.UNDEFINED, margin=Component.UNDEFINED, containerPadding=Component.UNDEFINED, rowHeight=Component.UNDEFINED, droppingItem=Component.UNDEFINED, isDraggable=Component.UNDEFINED, isResizable=Component.UNDEFINED, isBounded=Component.UNDEFINED, useCSSTransforms=Component.UNDEFINED, transformScale=Component.UNDEFINED, allowOverlap=Component.UNDEFINED, preventCollision=Component.UNDEFINED, isDroppable=Component.UNDEFINED, resizeHandles=Component.UNDEFINED, resizeHandle=Component.UNDEFINED, onLayoutChange=Component.UNDEFINED, onDrop=Component.UNDEFINED, onDropDragOver=Component.UNDEFINED, onBreakpointChange=Component.UNDEFINED, onWidthChange=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'allowOverlap', 'autoSize', 'breakpoints', 'class_name', 'cols', 'compactType', 'containerPadding', 'draggableCancel', 'draggableHandle', 'droppingItem', 'isBounded', 'isDraggable', 'isDroppable', 'isResizable', 'layout', 'layouts', 'margin', 'preventCollision', 'resizeHandle', 'resizeHandles', 'rowHeight', 'transformScale', 'useCSSTransforms', 'width']
        self._type = 'ResponsiveGridLayout'
        self._namespace = 'dash_grocery'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'allowOverlap', 'autoSize', 'breakpoints', 'class_name', 'cols', 'compactType', 'containerPadding', 'draggableCancel', 'draggableHandle', 'droppingItem', 'isBounded', 'isDraggable', 'isDroppable', 'isResizable', 'layout', 'layouts', 'margin', 'preventCollision', 'resizeHandle', 'resizeHandles', 'rowHeight', 'transformScale', 'useCSSTransforms', 'width']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(ResponsiveGridLayout, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Snake(Component):
    """A Snake component.
Wrapped from [react-snake](https://github.com/derrmru/react-snake).

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- backgroundColor (string; default '#ebebeb'):
    background.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color1 (string; default '#248ec2'):
    Snake's color.

- color2 (string; default '#1d355e'):
    Apple's color."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_grocery'
    _type = 'Snake'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, class_name=Component.UNDEFINED, color1=Component.UNDEFINED, color2=Component.UNDEFINED, backgroundColor=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'backgroundColor', 'class_name', 'color1', 'color2']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'backgroundColor', 'class_name', 'color1', 'color2']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Snake, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Clock(Component):
    """A Clock component.
Wrapped from [react-live-clock](https://github.com/pvoznyuk/react-live-clock).

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    date can be set as a children prop.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- blinking (string | boolean; optional):
    If you want the clock's last colon to blink. Set it to all to make
    them all blink.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- date (string; optional):
    Date to output, If nothing is set then it take current date.

- format (string; optional):
    Formatting from moment.js library.

- interval (number; optional):
    Auto-updating period for the clock. 1 second is a default value.

- locale (string; optional):
    Changes the language of the component via prop.

- ticking (boolean; optional):
    If you want the clock to be auto-updated every interval seconds.

- timezone (string; optional):
    If timezone is set, the date is show in this timezone. You can
    find the list. here, the TZ column."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_grocery'
    _type = 'Clock'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, class_name=Component.UNDEFINED, date=Component.UNDEFINED, format=Component.UNDEFINED, locale=Component.UNDEFINED, filter=Component.UNDEFINED, timezone=Component.UNDEFINED, ticking=Component.UNDEFINED, blinking=Component.UNDEFINED, interval=Component.UNDEFINED, onChange=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'blinking', 'class_name', 'date', 'format', 'interval', 'locale', 'ticking', 'timezone']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'blinking', 'class_name', 'date', 'format', 'interval', 'locale', 'ticking', 'timezone']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Clock, self).__init__(children=children, **args)
